module Tests.Common
    ( testzip, testfiles, lastfile, lastfilesize
    , world_txt
    , toUpper, toLower, map2
    ) where

import Data.Char (toUpper, toLower)

testzip = "Tests/test.zip"
testfiles = [ "hello/", "hello/world.txt" ]
lastfile = last testfiles
lastfilesize = 71 :: Integer

world_txt = "And God saw everything that he had made,\
            \ and behold, it was very good.\n"

-- map odd positions with f, even positions with g
map2 :: (a -> b) -> (a -> b) -> [a] -> [b]
map2 f g [] = []
map2 f g (x:xs) = (f x):map2 g f xs
